@@ -3,7 +3,7 @@
  * $Id: doxmlintf.h,v 1.29 2002/10/13 21:01:58 dimitri Exp $
  *
  *
- * Copyright (C) 1997-2006 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -45,6 +45,8 @@ class IString
     VIRTUAL_DESTRUCTOR(IString)
     /*! Returns a latin1 character representation of the string. */
     virtual const char *latin1() const = 0;
+    /*! Returns a utf8 character representation of the string. */
+    virtual const char *utf8() const = 0;
     /*! Returns a 16-bit unicode character representation of the character at 
      *  position \a index in the string. The first character is at index 0.
      */
@@ -1068,6 +1070,13 @@ class IPage : public ICompound
     virtual const IDocTitle *title() const = 0;
 };
 
+/** \brief Interface to a directory in the object model. */
+class IDir : public ICompound
+{
+  public:
+    virtual ICompoundIterator *nestedCompounds() const = 0;
+};
+
 /*! Root node of the object model. */
 class IDoxygen 
 {
