@@ -48,7 +48,8 @@ class ArgumentList;
 
 /** A class representing of a compound symbol.
  *
- *  A compound can be a class, struct, union, interface, or exception.
+ *  A compound can be a class, struct, union, interface, service, singleton,
+ *  or exception.
  *  \note This class should be renamed to CompoundDef
  */
 class ClassDef : public Definition
@@ -61,7 +62,9 @@ class ClassDef : public Definition
                         Interface, //=Entry::INTERFACE_SEC,
                         Protocol,  //=Entry::PROTOCOL_SEC,
                         Category,  //=Entry::CATEGORY_SEC,
-                        Exception  //=Entry::EXCEPTION_SEC
+                        Exception, //=Entry::EXCEPTION_SEC
+                        Service,   //=Entry::CLASS_SEC
+                        Singleton, //=Entry::CLASS_SEC
                       };
 
     /** Creates a new compound definition.
@@ -69,7 +72,10 @@ class ClassDef : public Definition
      *                   found.
      *  \param startLine line number where the definition of this compound
      *                   starts.
+     *  \param startColumn column number where the definition of this compound
+     *                   starts.
      *  \param name      the name of this compound (including scope)
+     *  \param symId     unique Id for this symbol
      *  \param ct        the kind of Compound
      *  \param ref       the tag file from which this compound is extracted
      *                   or 0 if the compound doesn't come from a tag file
@@ -82,7 +88,7 @@ class ClassDef : public Definition
      *                    I didn't add this to CompoundType to avoid having
      *                    to adapt all translators.
      */
-    ClassDef(const char *fileName,int startLine,
+    ClassDef(const char *fileName,int startLine,int startColumn,
              const char *name,CompoundType ct,
              const char *ref=0,const char *fName=0,
              bool isSymbol=TRUE,bool isJavaEnum=FALSE);
@@ -253,6 +259,9 @@ class ClassDef : public Definition
     /** Returns TRUE if this class is marked as sealed */
     bool isSealed() const;
 
+    /** Returns TRUE if this class is marked as published */
+    bool isPublished() const;
+
     /** Returns TRUE if this class represents an Objective-C 2.0 extension (nameless category) */
     bool isExtension() const;
 
@@ -310,14 +319,14 @@ class ClassDef : public Definition
     void setProtection(Protection p);
     void setGroupDefForAllMembers(GroupDef *g,Grouping::GroupPri_t pri,const QCString &fileName,int startLine,bool hasDocs);
     void addInnerCompound(Definition *d);
-    ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,
+    ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,int startColumn,
                                 const QCString &templSpec,bool &freshInstance);
     void addUsedClass(ClassDef *cd,const char *accessName,Protection prot);
     void addUsedByClass(ClassDef *cd,const char *accessName,Protection prot);
     void setIsStatic(bool b);
     void setCompoundType(CompoundType t);
     void setClassName(const char *name);
-    void setClassSpecifier(int spec);
+    void setClassSpecifier(uint64 spec);
 
     void setTemplateArguments(ArgumentList *al);
     void setTemplateBaseClassNames(QDict<int> *templateNames);
