@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: config.h,v 1.39 2001/03/19 19:27:40 root Exp $
+ * 
  *
  *
  * Copyright (C) 1997-2013 by Dimitri van Heesch.
@@ -42,7 +42,8 @@ class ConfigOption
       O_String,    //<! A single item
       O_Int,       //<! An integer value
       O_Bool,      //<! A boolean value
-      O_Obsolete   //<! An obsolete option
+      O_Obsolete,  //<! An obsolete option
+      O_Disabled   //<! Disabled compile time option
     };
     enum 
     { 
@@ -67,6 +68,7 @@ class ConfigOption
     QCString dependsOn() const { return m_dependency; }
     void addDependency(const char *dep) { m_dependency = dep; }
     void setEncoding(const QCString &e) { m_encoding = e; }
+    void setUserComment(const QCString &u) { m_userComment = u; }
 
   protected:
     virtual void writeTemplate(FTextStream &t,bool sl,bool upd) = 0;
@@ -75,7 +77,7 @@ class ConfigOption
     virtual void writeXML(FTextStream&) {}
     virtual void init() {}
 
-    QCString convertToComment(const QCString &s);
+    QCString convertToComment(const QCString &s, const QCString &u);
     void writeBoolValue(FTextStream &t,bool v);
     void writeIntValue(FTextStream &t,int i);
     void writeStringValue(FTextStream &t,QCString &s);
@@ -86,6 +88,7 @@ class ConfigOption
     QCString m_doc;
     QCString m_dependency;
     QCString m_encoding;
+    QCString m_userComment;
     OptionType m_kind;
 };
 
@@ -135,9 +138,13 @@ class ConfigList : public ConfigOption
       if (!sl)
       {
         t << endl;
-        t << convertToComment(m_doc);
+        t << convertToComment(m_doc, m_userComment);
         t << endl;
       }
+      else if (!m_userComment.isEmpty())
+      {
+        t << convertToComment("", m_userComment);
+      }
       t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       writeStringList(t,m_value);
       t << "\n";
@@ -175,9 +182,13 @@ class ConfigEnum : public ConfigOption
       if (!sl)
       {
         t << endl;
-        t << convertToComment(m_doc);
+        t << convertToComment(m_doc, m_userComment);
         t << endl;
       }
+      else if (!m_userComment.isEmpty())
+      {
+        t << convertToComment("", m_userComment);
+      }
       t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       writeStringValue(t,m_value);
       t << "\n";
@@ -216,9 +227,13 @@ class ConfigString : public ConfigOption
       if (!sl)
       {
         t << endl;
-        t << convertToComment(m_doc);
+        t << convertToComment(m_doc, m_userComment);
         t << endl;
       }
+      else if (!m_userComment.isEmpty())
+      {
+        t << convertToComment("", m_userComment);
+      }
       t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       writeStringValue(t,m_value);
       t << "\n";
@@ -259,9 +274,13 @@ class ConfigInt : public ConfigOption
       if (!sl)
       {
         t << endl;
-        t << convertToComment(m_doc);
+        t << convertToComment(m_doc, m_userComment);
         t << endl;
       }
+      else if (!m_userComment.isEmpty())
+      {
+        t << convertToComment("", m_userComment);
+      }
       t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       if (upd && !m_valueString.isEmpty())
       {
@@ -306,9 +325,13 @@ class ConfigBool : public ConfigOption
       if (!sl)
       {
         t << endl;
-        t << convertToComment(m_doc);
+        t << convertToComment(m_doc, m_userComment);
         t << endl;
       }
+      else if (!m_userComment.isEmpty())
+      {
+        t << convertToComment("", m_userComment);
+      }
       t << m_name << m_spaces.left(MAX_OPTION_LENGTH-m_name.length()) << "=";
       if (upd && !m_valueString.isEmpty())
       {
@@ -333,7 +356,19 @@ class ConfigBool : public ConfigOption
 class ConfigObsolete : public ConfigOption
 {
   public:
-    ConfigObsolete(const char *name,OptionType t) : ConfigOption(t)  
+    ConfigObsolete(const char *name) : ConfigOption(O_Obsolete)  
+    { m_name = name; }
+    void writeTemplate(FTextStream &,bool,bool) {}
+    void substEnvVars() {}
+    void writeXML(FTextStream&);
+};
+
+/** Section marker for compile time optional options
+ */
+class ConfigDisabled : public ConfigOption
+{
+  public:
+    ConfigDisabled(const char *name) : ConfigOption(O_Disabled)  
     { m_name = name; }
     void writeTemplate(FTextStream &,bool,bool) {}
     void substEnvVars() {}
@@ -515,11 +550,19 @@ class Config
     /*! Adds an option that has become obsolete. */
     ConfigOption *addObsolete(const char *name)
     {
-      ConfigObsolete *option = new ConfigObsolete(name,ConfigOption::O_Obsolete);
+      ConfigObsolete *option = new ConfigObsolete(name);
       m_dict->insert(name,option);
       m_obsolete->append(option);
       return option;
     }
+    /*! Adds an option that has been disabled at compile time. */
+    ConfigOption *addDisabled(const char *name)
+    {
+      ConfigDisabled *option = new ConfigDisabled(name);
+      m_dict->insert(name,option);
+      m_disabled->append(option);
+      return option;
+    }
     /*! @} */
 
     /*! Writes a template configuration to stream \a t. If \a shortIndex
@@ -570,12 +613,29 @@ class Config
      */
     void create();
 
+    /*! Append user comment
+     */
+    void appendUserComment(const QCString &u)
+    {
+      m_userComment += u;
+    }
+    /*! Take the user comment and reset it internally
+     *  \returns user comment
+     */
+    QCString takeUserComment()
+    {
+      QCString result=m_userComment;
+      m_userComment.resize(0);
+      return result;
+    }
+
   protected:
 
     Config()
     { 
       m_options  = new QList<ConfigOption>;
       m_obsolete = new QList<ConfigOption>;
+      m_disabled = new QList<ConfigOption>;
       m_dict     = new QDict<ConfigOption>(257);
       m_options->setAutoDelete(TRUE);
       m_obsolete->setAutoDelete(TRUE);
@@ -586,14 +646,17 @@ class Config
     {
       delete m_options;
       delete m_obsolete;
+      delete m_disabled;
       delete m_dict;
     }
 
   private:
     QList<ConfigOption> *m_options;
     QList<ConfigOption> *m_obsolete;
+    QList<ConfigOption> *m_disabled;
     QDict<ConfigOption> *m_dict;
     static Config *m_instance;
+    QCString m_userComment;
     bool m_initialized;
 };
 
