@@ -1,6 +1,6 @@
 # python script to generate configoptions.cpp from config.xml
 #
-# Copyright (C) 1997-2008 by Dimitri van Heesch.
+# Copyright (C) 1997-2013 by Dimitri van Heesch.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation under the terms of the GNU General Public License is hereby 
@@ -12,6 +12,7 @@
 # input used in their production; they are not affected by this license.
 #
 import xml.dom.minidom
+import sys
 from xml.dom import minidom, Node
 
 def addValues(var,node):
@@ -28,14 +29,19 @@ def parseOption(node):
 	defval  = node.getAttribute('defval')
 	adefval = node.getAttribute('altdefval')
 	depends = node.getAttribute('depends')
+	setting = node.getAttribute('setting')
 	# replace \ by \\, replace " by \", and '  ' by a newline with end string and start string at next line
         docC    = doc.strip().replace('\\','\\\\').replace('"','\\"').replace('  ','\\n"\n                 "')
+	if len(setting)>0:
+	    	print "#if %s" % (setting)
 	print "  //----"
         if type=='bool':
-        	if len(adefval)>0:
+	     	if len(adefval)>0:
 			enabled = adefval
+		elif defval=='1':
+			enabled = "TRUE"
 		else:
-			enabled = "TRUE" if defval=='1' else "FALSE"
+			enabled = "FALSE"
 		print "  cb = cfg->addBool("
 		print "                 \"%s\"," % (name)
 		print "                 \"%s\"," % (docC)
@@ -91,6 +97,10 @@ def parseOption(node):
 			print "  cl->setWidgetType(ConfigList::FileAndDir);"
 	elif type=='obsolete':
 		print "  cfg->addObsolete(\"%s\");" % (name)
+	if len(setting)>0:
+	    	print "#else"
+		print "  cfg->addDisabled(\"%s\");" % (name)
+	    	print "#endif"
 		
 
 
@@ -108,7 +118,7 @@ def parseGroups(node):
 	
 
 def main():
-	doc = xml.dom.minidom.parse("config.xml")
+	doc = xml.dom.minidom.parse(sys.argv[1])
 	elem = doc.documentElement
         print "/* WARNING: This file is generated!"
         print " * Do not edit this file, but edit config.xml instead and run"
@@ -118,6 +128,7 @@ def main():
         print "#include \"configoptions.h\""
         print "#include \"config.h\""
         print "#include \"portable.h\""
+        print "#include \"settings.h\""
         print ""
         print "void addConfigOptions(Config *cfg)"
         print "{"
