@@ -3,7 +3,7 @@
  * $Id: constexp.h,v 1.6 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -19,8 +19,8 @@
 #ifndef _CONSTEXP_H
 #define _CONSTEXP_H
 
-#include "qtbc.h"
 #include "cppvalue.h"
+#include <qcstring.h>
 
 extern bool parseCppExpression(const char *fileName,int line,const QCString &s);
 extern int cppExpYYparse();
