@@ -22,7 +22,6 @@
 #include <qdict.h>
 
 #include "types.h"
-#include "lockingptr.h"
 
 class FileDef;
 class OutputList;
@@ -89,13 +88,13 @@ class DefinitionIntf
  *  This can be a class or a member function, or a file, or a namespace, etc.
  *  Use definitionType() to find which type of definition this is.
  */
-class Definition : public DefinitionIntf, public LockableObj
+class Definition : public DefinitionIntf
 {
   public:
     
     /*! Create a new definition */
     Definition(
-        const char *defFileName,int defLine,
+        const char *defFileName,int defLine,int defColumn,
         const char *name,const char *b=0,const char *d=0,
         bool isSymbol=TRUE);
 
@@ -180,6 +179,9 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! returns the line number at which the definition was found */
     int getDefLine() const { return m_defLine; }
 
+    /*! returns the column number at which the definition was found */
+    int getDefColumn() const { return m_defColumn; }
+
     /*! Returns TRUE iff the definition is documented 
      *  (which could be generated documentation) 
      *  @see hasUserDocumentation()
@@ -243,18 +245,20 @@ class Definition : public DefinitionIntf, public LockableObj
     /** Returns the programming language this definition was written in. */
     SrcLangExt getLanguage() const;
 
-    LockingPtr<GroupList> partOfGroups() const;
+    GroupList *partOfGroups() const;
 
-    LockingPtr< QList<ListItemInfo> > xrefListItems() const;
+    QList<ListItemInfo> *xrefListItems() const;
 
     virtual Definition *findInnerCompound(const char *name);
     virtual Definition *getOuterScope() const;
 
-    LockingPtr<MemberSDict> getReferencesMembers() const;
-    LockingPtr<MemberSDict> getReferencedByMembers() const;
+    MemberSDict *getReferencesMembers() const;
+    MemberSDict *getReferencedByMembers() const;
 
     bool hasSections() const;
 
+    QCString id() const;
+
     //-----------------------------------------------------------------------------------
     // ----  setters -----
     //-----------------------------------------------------------------------------------
@@ -262,6 +266,9 @@ class Definition : public DefinitionIntf, public LockableObj
     /*! Sets a new \a name for the definition */
     void setName(const char *name);
 
+    /*! Sets a unique id for the symbol. Used for libclang integration. */
+    void setId(const char *name);
+
     /*! Sets the documentation of this definition to \a d. */
     virtual void setDocumentation(const char *d,const char *docFile,int docLine,bool stripWhiteSpace=TRUE);
 
@@ -328,12 +335,6 @@ class Definition : public DefinitionIntf, public LockableObj
 
   protected:
 
-    virtual void flushToDisk() const;
-    virtual void loadFromDisk() const;
-    virtual void makeResident() const;
-    void lock() const {}
-    void unlock() const {}
-
     Definition(const Definition &d);
 
   private: 
@@ -354,6 +355,7 @@ class Definition : public DefinitionIntf, public LockableObj
     bool m_isSymbol;
     QCString m_symbolName;
     int m_defLine;
+    int m_defColumn;
 };
 
 /** A list of Definition objects. */
