@@ -2,7 +2,7 @@
  *
  * $Id: $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,6 @@
 #ifndef DIRDEF_H
 #define DIRDEF_H
 
-#include "qtbc.h"
 #include "sortdict.h"
 #include "definition.h"
 
@@ -34,14 +33,14 @@ class FTextStream;
 
 class DirDef;
 
-/** A list of directories */
+/** A list of directories. */
 class DirList : public QList<DirDef>
 {
   public:
-   int compareItems(GCI item1,GCI item2);
+   int compareItems(QCollection::Item item1,QCollection::Item item2);
 };
 
-/** A directory */
+/** A model of a directory symbol. */
 class DirDef : public Definition
 {
   public:
@@ -54,7 +53,7 @@ class DirDef : public Definition
     QCString anchor() const { return QCString(); }
     bool isLinkableInProject() const;
     bool isLinkable() const;
-    QCString displayName() const { return m_dispName; }
+    QCString displayName(bool=TRUE) const { return m_dispName; }
     QCString shortName() const { return m_shortName; }
     void addSubDir(DirDef *subdir);
     FileList *   getFiles() const        { return m_fileList; }
@@ -74,6 +73,7 @@ class DirDef : public Definition
 
     static DirDef *mergeDirectoryInTree(const QCString &path);
     bool visited;
+    void setDiskName(const QCString &name) { m_diskName = name; }
 
   private:
     friend void computeDirDependencies();
@@ -96,6 +96,7 @@ class DirDef : public Definition
     DirList m_subdirs;
     QCString m_dispName;
     QCString m_shortName;
+    QCString m_diskName;
     FileList *m_fileList;                 // list of files in the group
     int m_dirCount;
     int m_level;
@@ -103,6 +104,7 @@ class DirDef : public Definition
     QDict<UsedDir> *m_usedDirs;
 };
 
+/** Class representing a pair of FileDef objects */
 class FilePair 
 {
   public:
@@ -114,14 +116,15 @@ class FilePair
     FileDef *m_dst;
 };
 
+/** A sorted dictionary of FilePair objects. */
 class FilePairDict : public SDict<FilePair>
 {
   public:
     FilePairDict(int size) : SDict<FilePair>(size) {}
-    int compareItems(GCI item1,GCI item2);
+    int compareItems(QCollection::Item item1,QCollection::Item item2);
 };
 
-/** Usage information of a directory . */
+/** Usage information of a directory. */
 class UsedDir
 {
   public:
@@ -139,7 +142,7 @@ class UsedDir
     bool m_inherited;
 };
 
-/** A usage relation between two direction. */
+/** A usage relation between two directories. */
 class DirRelation
 {
   public:
@@ -156,18 +159,19 @@ class DirRelation
     UsedDir *m_dst;
 };
 
-inline int DirList::compareItems(GCI item1,GCI item2)
+inline int DirList::compareItems(QCollection::Item item1,QCollection::Item item2)
 {
-  return stricmp(((DirDef *)item1)->shortName(),((DirDef *)item2)->shortName());
+  return qstricmp(((DirDef *)item1)->shortName(),((DirDef *)item2)->shortName());
 }
 
+/** A sorted dictionary of DirDef objects. */
 class DirSDict : public SDict<DirDef>
 {
   public:
     DirSDict(int size) : SDict<DirDef>(size) {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
-      return stricmp(((DirDef *)item1)->shortName(),((DirDef *)item2)->shortName());
+      return qstricmp(((DirDef *)item1)->shortName(),((DirDef *)item2)->shortName());
     }
 };
 
