@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,7 @@
 
 #include <qcstring.h>
 #include <qlist.h>
+#include <stdio.h>
 #include "htmlattrib.h"
 
 class Definition;
@@ -59,9 +60,12 @@ enum Tokens
   RetVal_EndTable       = 0x10010,
   RetVal_Internal       = 0x10011,
   RetVal_SwitchLang     = 0x10012,
-  RetVal_CloseXml       = 0x10013
+  RetVal_CloseXml       = 0x10013,
+  RetVal_EndBlockQuote  = 0x10014,
+  RetVal_CopyDoc        = 0x10015
 };
 
+/** @brief Data associated with a token used by the comment block parser. */
 struct TokenInfo
 {
   // unknown token
@@ -133,6 +137,8 @@ void doctokenizerYYsetStateHtmlOnly();
 void doctokenizerYYsetStateManOnly();
 void doctokenizerYYsetStateLatexOnly();
 void doctokenizerYYsetStateXmlOnly();
+void doctokenizerYYsetStateDbOnly();
+void doctokenizerYYsetStateRtfOnly();
 void doctokenizerYYsetStateVerbatim();
 void doctokenizerYYsetStateDot();
 void doctokenizerYYsetStateMsc();
