@@ -113,6 +113,7 @@ Entry::Entry(const Entry &e)
   anchors     = new QList<SectionInfo>;
   fileName    = e.fileName;
   startLine   = e.startLine;
+  startColumn = e.startColumn;
   if (e.sli)
   {
     sli = new QList<ListItemInfo>;
@@ -132,6 +133,7 @@ Entry::Entry(const Entry &e)
   hidden      = e.hidden;
   artificial  = e.artificial;
   groupDocType = e.groupDocType;
+  id          = e.id;
 
   m_parent    = e.m_parent;
   m_sublist   = new QList<Entry>;
@@ -239,6 +241,7 @@ void Entry::reset()
   initializer.resize(0);
   initLines = -1;
   startLine = 1;
+  startColumn = 1;
   bodyLine = -1;
   endBodyLine = -1;
   mGrpId = -1;
@@ -257,6 +260,7 @@ void Entry::reset()
   subGrouping = TRUE;
   protection = Public;
   groupDocType = GROUPDOC_NORMAL;
+  id.resize(0);
   m_sublist->clear();
   extends->clear();
   groups->clear();
