@@ -1,7 +1,7 @@
 /******************************************************************************
  * ftvhelp.cpp,v 1.0 2000/09/06 16:09:00
  *
- * Copyright (C) 1997-2012 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,8 @@
 #include "pagedef.h"
 #include "docparser.h"
 #include "htmldocvisitor.h"
+#include "filedef.h"
+#include "util.h"
 
 #define MAX_INDENT 1024
 
@@ -885,8 +887,9 @@ static void generateBriefDoc(FTextStream &t,Definition *def)
   {
     DocNode *root = validatingParseDoc(def->briefFile(),def->briefLine(),
         def,0,brief,FALSE,FALSE,0,TRUE,TRUE);
-    HtmlGenerator htmlGen;
-    HtmlDocVisitor *visitor = new HtmlDocVisitor(t,htmlGen,0);
+    QCString relPath = relativePathToRoot(def->getOutputFileBase());
+    HtmlCodeGenerator htmlGen(t,relPath);
+    HtmlDocVisitor *visitor = new HtmlDocVisitor(t,htmlGen,def,0);
     root->accept(visitor);
     delete visitor;
     delete root;
@@ -1024,7 +1027,7 @@ class NavIndexEntryList : public QList<NavIndexEntry>
   public:
     NavIndexEntryList() : QList<NavIndexEntry>() { setAutoDelete(TRUE); }
    ~NavIndexEntryList() {}
-    int compareItems(GCI item1,GCI item2)
+    int compareItems(QCollection::Item item1,QCollection::Item item2)
     {
       // sort list based on url
       return qstrcmp(((NavIndexEntry*)item1)->url,((NavIndexEntry*)item2)->url);
@@ -1257,6 +1260,8 @@ static void generateJSNavTree(const QList<FTVNode> &nodeList)
       tsidx << "};" << endl;
       t << endl << "];" << endl;
     }
+    t << endl << "var SYNCONMSG = '"  << theTranslator->trPanelSynchronisationTooltip(FALSE) << "';"; 
+    t << endl << "var SYNCOFFMSG = '" << theTranslator->trPanelSynchronisationTooltip(TRUE)  << "';"; 
     t << endl << navtree_script;
   }
 }
@@ -1293,7 +1298,11 @@ void FTVHelp::generateTreeViewScripts()
     if (f.open(IO_WriteOnly))
     {
       FTextStream t(&f);
-      t << replaceColorMarkers(navtree_css);
+      t << substitute(
+              replaceColorMarkers(navtree_css),
+              "$width",
+              QCString().setNum(Config_getInt("TREEVIEW_WIDTH"))+"px"
+             );
     }
   }
 }
