@@ -39,26 +39,30 @@ static const char types[][NUM_HTML_LIST_TYPES] = {"1", "a", "i", "A"};
 static QCString convertIndexWordToAnchor(const QString &word)
 {
   static char hex[] = "0123456789abcdef";
-  uint i;
   QCString result;
-  for (i=0;i<word.length();i++)
+  const char *str = word.data();
+  unsigned char c;
+  while ((c = *str++)) 
   {
-    int c = word.at(i);
-    if (isId(c))
+    if ((c >= 'a' && c <= 'z') || // ALPHA
+        (c >= 'A' && c <= 'A') || // ALPHA
+        (c >= '0' && c <= '9') || // DIGIT
+        c == '-' || 
+        c == '.' || 
+        c == '_' || 
+        c == '~'
+       )
     {
-      result+=c;
+      result += c;
     }
-    else if (isspace(c))
+    else 
     {
-      result+="_";
-    }
-    else
-    {
-      char cs[3];
-      cs[0]=hex[c>>4];
-      cs[1]=hex[c&0xf];
-      cs[2]=0;
-      result+=cs;
+      char enc[4];
+      enc[0] = '%';
+      enc[1] = hex[(c & 0xf0) >> 4];
+      enc[2] = hex[c & 0xf];
+      enc[3] = 0;
+      result += enc;
     }
   }
   return result;
@@ -153,6 +157,7 @@ void HtmlDocVisitor::visit(DocWord *w)
 void HtmlDocVisitor::visit(DocLinkedWord *w)
 {
   if (m_hide) return;
+  //printf("linked word: %s\n",w->word().data());
   startLink(w->ref(),w->file(),w->relPath(),w->anchor(),w->tooltip());
   filter(w->word());
   endLink();
@@ -277,7 +282,7 @@ void HtmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::LeftFloor:     m_t << "&lfloor;"; break;
     case DocSymbol::RightFloor:    m_t << "&rfloor;"; break;
     default:
-       err("error: unknown symbol found\n");
+       err("unknown symbol found\n");
   }
 }
 
@@ -447,7 +452,8 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::ManOnly: 
     case DocVerbatim::LatexOnly: 
     case DocVerbatim::XmlOnly: 
-    case DocVerbatim::RtfOnly: 
+    case DocVerbatim::RtfOnly:
+    case DocVerbatim::DocbookOnly:
       /* nothing */ 
       break;
 
@@ -536,7 +542,7 @@ void HtmlDocVisitor::visit(DocInclude *inc)
                                         -1,    // endLine
                                         TRUE,  // inlineFragment
                                         0,     // memberDef
-                                        TRUE,  // show line numbers
+                                        FALSE, // show line numbers
                                         m_ctx  // search context 
                                        );
       m_t << PREFRAG_END;
@@ -1833,11 +1839,11 @@ void HtmlDocVisitor::filterQuotedCdataAttr(const char* str)
        // it's enough to replace these two, provided that the declaration
        // for the HTML version we generate (and as supported by the browser)
        // specifies that all the other symbols used in rawVal are
-       // within the right charachter class (i.e., they're not
-       // some multinational weird charachters not in the BASESET).
+       // within the right character class (i.e., they're not
+       // some multinational weird characters not in the BASESET).
        // We assume that 1) the browser will support whatever is remaining
        // in the formula and 2) the TeX formulae are generally governed
-       // by even stricter charachter restrictions so it should be enough.
+       // by even stricter character restrictions so it should be enough.
        //
        // On some incompliant browsers, additional translation of
        // '>' and '<' into "&gt;" and "&lt;", respectively, might be needed;
