@@ -15,6 +15,7 @@
  * input used in their production; they are not affected by this license.
  *
  */
+#include "htmlattrib.h"
 #include <qfileinfo.h> 
 #include "latexdocvisitor.h"
 #include "docparser.h"
@@ -26,7 +27,6 @@
 #include "message.h"
 #include "parserintf.h"
 #include "msc.h"
-#include "htmlattrib.h"
 #include "cite.h"
 #include "filedef.h"
 #include "config.h"
@@ -257,7 +257,7 @@ void LatexDocVisitor::visit(DocSymbol *s)
     case DocSymbol::LeftFloor:     m_t << "{$\\lfloor$}"; break;
     case DocSymbol::RightFloor:    m_t << "{$\\rfloor$}"; break;
     default:
-                             err("error: unknown symbol found\n");
+                             err("unknown symbol found\n");
   }
 }
 
@@ -358,7 +358,8 @@ void LatexDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::XmlOnly: 
     case DocVerbatim::ManOnly: 
-    case DocVerbatim::RtfOnly: 
+    case DocVerbatim::RtfOnly:
+    case DocVerbatim::DocbookOnly:
       /* nothing */ 
       break;
     case DocVerbatim::LatexOnly: 
@@ -423,10 +424,10 @@ void LatexDocVisitor::visit(DocVerbatim *s)
 void LatexDocVisitor::visit(DocAnchor *anc)
 {
   if (m_hide) return;
-  m_t << "\\label{" << anc->file() << "_" << anc->anchor() << "}%" << endl;
+  m_t << "\\label{" << stripPath(anc->file()) << "_" << anc->anchor() << "}%" << endl;
   if (!anc->file().isEmpty() && Config_getBool("PDF_HYPERLINKS")) 
   {
-    m_t << "\\hypertarget{" << anc->file() << "_" << anc->anchor() 
+    m_t << "\\hypertarget{" << stripPath(anc->file()) << "_" << anc->anchor() 
       << "}{}%" << endl;
   }    
 }
@@ -797,11 +798,11 @@ void LatexDocVisitor::visitPre(DocSection *s)
   if (m_hide) return;
   if (Config_getBool("PDF_HYPERLINKS"))
   {
-    m_t << "\\hypertarget{" << s->file() << "_" << s->anchor() << "}{}";
+    m_t << "\\hypertarget{" << stripPath(s->file()) << "_" << s->anchor() << "}{}";
   }
   m_t << "\\" << getSectionName(s->level()) << "{";
   filter(convertCharEntitiesToUTF8(s->title().data()));
-  m_t << "}\\label{" << s->file() << "_" << s->anchor() << "}" << endl;
+  m_t << "}\\label{" << stripPath(s->file()) << "_" << s->anchor() << "}" << endl;
 }
 
 void LatexDocVisitor::visitPost(DocSection *) 
