@@ -64,7 +64,7 @@ static bool elemIsVisible(const QXmlAttributes &attrib,bool defVal=TRUE)
     }
     else if (!opt)
     {
-      err("error: found unsupported value %s for visible attribute in layout file\n",
+      err("found unsupported value %s for visible attribute in layout file\n",
           visible.data());
     }
   }
@@ -120,7 +120,7 @@ QCString LayoutNavEntry::url() const
     }
     if (!found)
     {
-      msg("warning: explicit link request to '%s' in layout file '%s' could not be resolved\n",qPrint(url.mid(5)),qPrint(Config_getString("LAYOUT_FILE")));
+      msg("explicit link request to '%s' in layout file '%s' could not be resolved\n",qPrint(url.mid(5)),qPrint(Config_getString("LAYOUT_FILE")));
     }
   }
   //printf("LayoutNavEntry::url()=%s\n",url.data());
@@ -313,6 +313,12 @@ class LayoutParser : public QXmlDefaultHandler
                                            SrcLangExt_VHDL,VhdlDocGen::trVhdlType(VhdlDocGen::ENTITY,FALSE),
                                            SrcLangExt_Fortran,theTranslator->trDataTypes()
                                          )));
+      m_sHandler.insert("class/memberdecl/services",
+          new StartElementHandlerMember(this,&LayoutParser::startMemberDeclEntry,
+                                        MemberListType_services,theTranslator->trServices()));
+      m_sHandler.insert("class/memberdecl/interfaces",
+          new StartElementHandlerMember(this,&LayoutParser::startMemberDeclEntry,
+                                        MemberListType_interfaces,theTranslator->trInterfaces()));
       m_sHandler.insert("class/memberdecl/publictypes", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDeclEntry,
                                         MemberListType_pubTypes,theTranslator->trPublicTypes()));
@@ -422,6 +428,12 @@ class LayoutParser : public QXmlDefaultHandler
       m_sHandler.insert("class/memberdef/enums", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberListType_enumMembers,theTranslator->trMemberEnumerationDocumentation()));
+      m_sHandler.insert("class/memberdef/services",
+          new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
+                                        MemberListType_serviceMembers,theTranslator->trInterfaces()));
+      m_sHandler.insert("class/memberdef/interfaces",
+          new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
+                                        MemberListType_interfaceMembers,theTranslator->trInterfaces()));
       m_sHandler.insert("class/memberdef/constructors", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDefEntry,
                                         MemberListType_constructors,theTranslator->trConstructorDocumentation()));
@@ -465,12 +477,16 @@ class LayoutParser : public QXmlDefaultHandler
           new StartElementHandler(this,&LayoutParser::startMemberDecl));
       m_sHandler.insert("namespace/memberdecl/nestednamespaces", 
           new StartElementHandlerSection(this,LayoutDocEntry::NamespaceNestedNamespaces,&LayoutParser::startSectionEntry,
-                                         COMPILE_FOR_3_OPTIONS(
+                                         COMPILE_FOR_4_OPTIONS(
                                            theTranslator->trNamespaces(),
                                            SrcLangExt_Java,theTranslator->trPackages(),
                                            SrcLangExt_VHDL,theTranslator->trPackages(),
+                                           SrcLangExt_IDL,theTranslator->trModules(),
                                            SrcLangExt_Fortran,theTranslator->trModules()
                                          )));
+      m_sHandler.insert("namespace/memberdecl/constantgroups",
+          new StartElementHandlerSection(this,LayoutDocEntry::NamespaceNestedConstantGroups,&LayoutParser::startSectionEntry,
+                                         theTranslator->trConstantGroups()));
       m_sHandler.insert("namespace/memberdecl/classes", 
           new StartElementHandlerSection(this,LayoutDocEntry::NamespaceClasses,&LayoutParser::startSectionEntry,
                                          COMPILE_FOR_2_OPTIONS(
@@ -559,11 +575,15 @@ class LayoutParser : public QXmlDefaultHandler
                                          )));
       m_sHandler.insert("file/memberdecl/namespaces", 
           new StartElementHandlerSection(this,LayoutDocEntry::FileNamespaces,&LayoutParser::startSectionEntry,
-                                         COMPILE_FOR_2_OPTIONS(
+                                         COMPILE_FOR_3_OPTIONS(
                                            theTranslator->trNamespaces(),
                                            SrcLangExt_Java,theTranslator->trPackages(),
+                                           SrcLangExt_IDL,theTranslator->trModules(),
                                            SrcLangExt_Fortran,theTranslator->trModules()
                                          )));
+      m_sHandler.insert("file/memberdecl/constantgroups",
+          new StartElementHandlerSection(this,LayoutDocEntry::FileNamespaces,&LayoutParser::startSectionEntry,
+                                         theTranslator->trConstantGroups()));
       m_sHandler.insert("file/memberdecl/defines", 
           new StartElementHandlerMember(this,&LayoutParser::startMemberDeclEntry,
                                         MemberListType_decDefineMembers,theTranslator->trDefines()));
@@ -1041,11 +1061,11 @@ class LayoutParser : public QXmlDefaultHandler
       {
         if (type.isEmpty())
         {
-          err("error: an entry tag within a navindex has no type attribute! Check your layout file!\n");
+          err("an entry tag within a navindex has no type attribute! Check your layout file!\n");
         }
         else
         {
-          err("error: the type '%s' is not supported for the entry tag within a navindex! Check your layout file!\n",type.data());
+          err("the type '%s' is not supported for the entry tag within a navindex! Check your layout file!\n",type.data());
         }
         m_invalidEntry=TRUE;
         return;
@@ -1219,7 +1239,7 @@ class LayoutParser : public QXmlDefaultHandler
       }
       else
       {
-        err("error: Unexpected start tag `%s' found in scope='%s'!\n",
+        err("Unexpected start tag `%s' found in scope='%s'!\n",
             name.data(),m_scope.data());
       }
       return TRUE;
@@ -1269,21 +1289,21 @@ class LayoutErrorHandler : public QXmlErrorHandler
     LayoutErrorHandler(const char *fn) : fileName(fn) {}
     bool warning( const QXmlParseException &exception )
     {
-      err("warning: at line %d column %d of %s: %s\n",
+      warn_uncond("at line %d column %d of %s: %s\n",
           exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
     bool error( const QXmlParseException &exception )
     {
-      err("error: at line %d column %d of %s: %s\n",
+      err("at line %d column %d of %s: %s\n",
           exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
     }
     bool fatalError( const QXmlParseException &exception )
     {
-      err("fatal error: at line %d column %d of %s: %s\n",
+      err("fatal: at line %d column %d of %s: %s\n",
           exception.lineNumber(),exception.columnNumber(),fileName.data(),
           exception.message().data());
       return FALSE;
