@@ -44,7 +44,7 @@ class MemberDef : public Definition
 {
   public:
     
-    MemberDef(const char *defFileName,int defLine,
+    MemberDef(const char *defFileName,int defLine,int defColumn,
               const char *type,const char *name,const char *args,
               const char *excp,Protection prot,Specifier virt,bool stat,
               Relationship related,MemberType t,const ArgumentList *tal,
@@ -73,7 +73,7 @@ class MemberDef : public Definition
     const char *extraTypeChars() const;
     const QCString &initializer() const;
     int initializerLines() const;
-    int  getMemberSpecifiers() const;
+    uint64 getMemberSpecifiers() const;
     MemberList *getSectionList(Definition *d) const;
 
     // scope query members
@@ -148,6 +148,16 @@ class MemberDef : public Definition
     bool isDefault() const;
     bool isDelete() const;
     bool isNoExcept() const;
+    bool isAttribute() const; // UNO IDL attribute
+    bool isUNOProperty() const; // UNO IDL property
+    bool isReadonly() const;
+    bool isBound() const;
+    bool isConstrained() const;
+    bool isTransient() const;
+    bool isMaybeVoid() const;
+    bool isMaybeDefault() const;
+    bool isMaybeAmbiguous() const;
+    bool isPublished() const; // UNO IDL published
     bool isTemplateSpecialization() const;
     bool hasDocumentedParams() const;
     bool hasDocumentedReturnType() const;
@@ -158,6 +168,7 @@ class MemberDef : public Definition
     bool hasOneLineInitializer() const;
     bool hasMultiLineInitializer() const;
     bool protectionVisible() const;
+    bool showInCallGraph() const;
 
     // output info
     bool isLinkableInProject() const;
@@ -171,7 +182,7 @@ class MemberDef : public Definition
     bool isDocumentedFriendClass() const;
 
     MemberDef *reimplements() const;
-    LockingPtr< MemberList > reimplementedBy() const;
+    MemberList *reimplementedBy() const;
     bool isReimplementedBy(ClassDef *cd) const;
 
     //int inbodyLine() const;
@@ -184,19 +195,19 @@ class MemberDef : public Definition
     MemberDef *getAnonymousEnumType() const;
     bool isDocsForDefinition() const;
     MemberDef *getEnumScope() const;
-    LockingPtr< MemberList > enumFieldList() const;
+    MemberList *enumFieldList() const;
     void setEnumBaseType(const QCString &type);
     QCString enumBaseType() const;
 
     bool hasExamples();
-    LockingPtr<ExampleSDict> getExamples() const;
+    ExampleSDict *getExamples() const;
     bool isPrototype() const;
 
     // argument related members
-    LockingPtr<ArgumentList> argumentList() const;
-    LockingPtr<ArgumentList> declArgumentList() const;
-    LockingPtr<ArgumentList> templateArguments() const;
-    LockingPtr< QList<ArgumentList> > definitionTemplateParameterLists() const;
+    ArgumentList *argumentList() const;
+    ArgumentList *declArgumentList() const;
+    ArgumentList *templateArguments() const;
+    QList<ArgumentList> *definitionTemplateParameterLists() const;
 
     // member group related members
     int getMemberGroupId() const;
@@ -240,8 +251,8 @@ class MemberDef : public Definition
     void setFileDef(FileDef *fd);
     void setAnchor();
     void setProtection(Protection p);
-    void setMemberSpecifiers(int s);
-    void mergeMemberSpecifiers(int s);
+    void setMemberSpecifiers(uint64 s);
+    void mergeMemberSpecifiers(uint64 s);
     void setInitializer(const char *i);
     void setBitfields(const char *s);
     void setMaxInitLines(int lines);
@@ -274,7 +285,7 @@ class MemberDef : public Definition
 
     // enumeration specific members
     void insertEnumField(MemberDef *md);
-    void setEnumScope(MemberDef *md);
+    void setEnumScope(MemberDef *md,bool livesInsideEnum=FALSE);
     void setEnumClassScope(ClassDef *cd);
     void setDocumentedEnumValues(bool value);
     void setAnonymousEnumType(MemberDef *md);
@@ -341,14 +352,16 @@ class MemberDef : public Definition
     // output generation
     void writeDeclaration(OutputList &ol,
                    ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd,
-                   bool inGroup,ClassDef *inheritFrom=0,const char *inheritId=0); 
+                   bool inGroup, const DefType compoundType,
+                   ClassDef *inheritFrom=0,const char *inheritId=0); 
     void writeDocumentation(MemberList *ml,OutputList &ol,
                             const char *scopeName,Definition *container,
                             bool inGroup,bool showEnumValues=FALSE,bool
                             showInline=FALSE);
     void writeMemberDocSimple(OutputList &ol,Definition *container);
     void writeEnumDeclaration(OutputList &typeDecl,
-            ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
+            ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd, 
+            const DefType compoundType);
     void warnIfUndocumented();
     
     MemberDef *createTemplateInstanceMember(ArgumentList *formalArgs,
@@ -380,7 +393,7 @@ class MemberDef : public Definition
                           const QCString &cfname,const QCString &ciname,
                           const QCString &cname);
     void _writeCategoryRelation(OutputList &ol);
-    void _writeTagData();
+    void _writeTagData(const DefType);
     void _addToSearchIndex();
 
     static int s_indentLevel;
@@ -393,9 +406,6 @@ class MemberDef : public Definition
                    bool onlyText=FALSE);
 
     MemberDefImpl *m_impl;
-    int m_cacheHandle;
-    off_t m_storagePos;     // location where the item is stored in file (if impl==0)
-    bool m_flushPending;
     uchar m_isLinkableCached;    // 0 = not cached, 1=FALSE, 2=TRUE
     uchar m_isConstructorCached; // 0 = not cached, 1=FALSE, 2=TRUE
     uchar m_isDestructorCached;  // 0 = not cached, 1=FALSE, 2=TRUE
