@@ -71,8 +71,6 @@ class CodeOutputInterface
     virtual void startFontClass(const char *) = 0;
     virtual void endFontClass() = 0;
     virtual void writeCodeAnchor(const char *name) = 0;
-    virtual void linkableSymbol(int line,const char *symName,
-                 Definition *symDef,Definition *context) = 0;
     virtual void setCurrentDoc(Definition *context,const char *anchor,bool isSourceFile) = 0;
     virtual void addWord(const char *word,bool hiPriority) = 0;
 };
@@ -98,7 +96,7 @@ class BaseOutputDocInterface : public CodeOutputInterface
                         Examples 
                       };
 
-    virtual void parseText(const QCString &)  {}
+    virtual bool parseText(const QCString &s)  { return s.isEmpty(); }
     
     /*! Start of a bullet list: e.g. \c \<ul\> in html. startItemListItem() is
      *  Used for the bullet items.
@@ -406,6 +404,7 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endParameterName(bool,bool,bool) = 0;
     virtual void startParameterList(bool) = 0;
     virtual void endParameterList() = 0;
+    virtual void exceptionEntry(const char*,bool) = 0;
 
     virtual void startConstraintList(const char *) = 0;
     virtual void startConstraintParam() = 0;
