@@ -2,7 +2,7 @@
  *
  * $Id: pre.h,v 1.10 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2013 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,10 +18,6 @@
 #ifndef PRE_H
 #define PRE_H
 
-#include "qtbc.h"
-#include <stdio.h>
-#include "define.h"
-
 class BufStr;
 
 void initPreprocessor();
