@@ -311,7 +311,7 @@ void RTFDocVisitor::visit(DocSymbol *s)
     case DocSymbol::LeftFloor:       m_t << "lfloor "; break;
     case DocSymbol::RightFloor:      m_t << "rfloor "; break;
     default:
-                             err("error: unknown symbol found\n");
+                             err("unknown symbol found\n");
   }
   m_lastIsPara=FALSE;
 }
@@ -446,7 +446,8 @@ void RTFDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::LatexOnly: 
     case DocVerbatim::XmlOnly: 
-    case DocVerbatim::ManOnly: 
+    case DocVerbatim::ManOnly:
+    case DocVerbatim::DocbookOnly:
       /* nothing */
       break;
     case DocVerbatim::Dot: 
