@@ -21,6 +21,6 @@
 
 class Entry;
 
-void parseTagFile(Entry *root,const char *fullPathName,const char *fileName);
+void parseTagFile(Entry *root,const char *fullPathName);
 
 #endif
