@@ -127,7 +127,7 @@ void TextDocVisitor::visit(DocSymbol *s)
     case DocSymbol::LeftFloor:     m_t << "&lfloor;"; break;
     case DocSymbol::RightFloor:    m_t << "&rfloor;"; break;
     default:
-                             err("error: unknown symbol found\n");
+                             err("unknown symbol found\n");
   }
 }
 
