@@ -71,89 +71,89 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! return the language charset. This will be used for the HTML output */
     virtual QCString idLanguageCharset()
     {
-      return "cp1256";
+      return "utf-8";
     }
 
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
     virtual QCString trRelatedFunctions()
-    { return "  "; }
+    { return "دوال ذات صلة"; }
 
     /*! subscript for the related functions. */
     virtual QCString trRelatedSubscript()
-    { return "(     )"; }
+    { return "(لاحظ أن هذه الدوال ليست أعضاء)"; }
 
     /*! header that is put before the detailed description of files, classes and namespaces. */
     virtual QCString trDetailedDescription()
-    { return " "; }
+    { return "وصف تفصيلي"; }
 
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
-    { return "   "; }
+    { return "توثيق تعريفات النوع الأعضاء"; }
     
     /*! header that is put before the list of enumerations. */
     virtual QCString trMemberEnumerationDocumentation()
-    { return "  "; }
+    { return "توثيق العدديات الأعضاء"; }
     
     /*! header that is put before the list of member functions. */
     virtual QCString trMemberFunctionDocumentation()
-    { return "  "; }
+    { return "توثيق الدوال الأعضاء"; }
     
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return " "; 
+        return "توثيق الحقل"; 
       }
       else
       {
-        return "  "; 
+        return "توثيق البيان العضو"; 
       }
     }
 
     /*! this is the text of a link put after brief descriptions. */
     virtual QCString trMore() 
-    { return " ..."; }
+    { return "المزيد ..."; }
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "  "; }
+    { return "اعرض كل الأعضاء"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
-    { return " "; }
+    { return "قائمة الأعضاء"; }
 
     /*! this is the first part of a sentence that is followed by a class name */
     virtual QCString trThisIsTheListOfAllMembers()
-    { return "     "; }
+    { return "هذه فائمة بكل الأعضاء في "; }
 
     /*! this is the remainder of the sentence after the class name */
     virtual QCString trIncludingInheritedMembers()
-    { return ",    "; }
+    { return ", متضمنة كل الأعضاء الموروثة"; }
     
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
     virtual QCString trGeneratedAutomatically(const char *s)
-    { QCString result="    Doxygen";
-      if (s) result+=(QCString)"  "+s;
-      result+="   ."; 
+    { QCString result="تم تكوينها آليا بواسطة Doxygen";
+      if (s) result+=(QCString)" لـ "+s;
+      result+=" من ملفات المصدر."; 
       return result;
     }
 
     /*! put after an enum name in the list of all members */
     virtual QCString trEnumName()
-    { return " "; }
+    { return "الإسم العددي"; }
     
     /*! put after an enum value in the list of all members */
     virtual QCString trEnumValue()
-    { return " "; }
+    { return "القيمة العددية"; }
     
     /*! put after an undocumented member in the list of all members */
     virtual QCString trDefinedIn()
-    { return " "; }
+    { return "معرف في"; }
 
     // quick reference sections
 
@@ -161,43 +161,43 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  compounds or files (see the \\group command).
      */
     virtual QCString trModules()
-    { return ""; }
+    { return "مكونات"; }
     
     /*! This is put above each page as a link to the class hierarchy */
     virtual QCString trClassHierarchy()
-    { return "  "; }
+    { return "الشكل الهرمي للفئة"; }
     
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return " ";
+        return "هياكل البيانات";
       }
       else
       {
-        return " "; 
+        return "قائمة الفئات"; 
       }
     }
     
     /*! This is put above each page as a link to the list of documented files */
     virtual QCString trFileList()
-    { return " "; }
+    { return "قائمة الملفات"; }
 
     /*! This is put above each page as a link to the list of all verbatim headers */
     virtual QCString trHeaderFiles()
-    { return " "; }
+    { return "الملفات الرأسية"; }
 
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return " "; 
+        return "حقول البيانات"; 
       }
       else
       {
-        return " "; 
+        return "أعضاء الفئة"; 
       }
     }
 
@@ -206,38 +206,38 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return ""; 
+        return "العوام"; 
       }
       else
       {
-        return " "; 
+        return "أعضاء الملف"; 
       }
     }
 
     /*! This is put above each page as a link to all related pages. */
     virtual QCString trRelatedPages()
-    { return "  "; }
+    { return "صفحات ذات صلة"; }
 
     /*! This is put above each page as a link to all examples. */
     virtual QCString trExamples()
-    { return ""; }
+    { return "أمثلة"; }
 
     /*! This is put above each page as a link to the search engine. */
     virtual QCString trSearch()
-    { return ""; }
+    { return "بحث"; }
 
     /*! This is an introduction to the class hierarchy. */
     virtual QCString trClassHierarchyDescription()
-    { return "         "
-             "   :";
+    { return "قائمة التوارث هذه تم ترتيبها أبجديا بصورة تقريبية ، "
+             "ولكن ليس بصورة تامة:";
     }
 
     /*! This is an introduction to the list with all files. */
     virtual QCString trFileListDescription(bool extractAll)
     {
-      QCString result="   ";
-      if (!extractAll) result+=" ";
-	  result+="   :";
+      QCString result="هذه قائمة بكل الملفات";
+      if (!extractAll) result+="الموثقة ";
+	  result+="مع وصف مختصر :";
       return result;
     }
 
@@ -247,53 +247,53 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
       
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "      :"; 
+        return "هذه هي هياكل البيانات مع وصف مختصر:"; 
       }
       else
       {
-        return "     "
-			"    :"; 
+        return "هذه هي الفئات ، البناءات ،"
+			"الإتحادات والواجهات مع وصف مختصر:"; 
       }
     }
 
     /*! This is an introduction to the page with all class members. */
     virtual QCString trCompoundMembersDescription(bool extractAll)
     {
-      QCString result="   ";
+      QCString result="هذه قائمة بكل ";
       
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        result+="  ";
+        result+="حقول البناءات والإتحادات";
       }
       else
       {
-        result+=" ";
+        result+="أعضاء الفئة";
       }
 	  if (!extractAll)
       {
-        result+="  ";
+        result+=" الموثقة ";
       }
-      result+="    ";
+      result+=" مع وصلات إلى ";
       if (!extractAll) 
       {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
-          result+=" /  :";
+          result+="توثيق البناء/الإتحاد لكل حقل:";
         }
         else
         {
-          result+="   :";
+          result+="توثيق الفئة لكل عضو:";
         }
       }
       else 
       {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
-          result+="/   :";
+          result+="البناءات/الإتحادات التي ينتمون إليها:";
         }
         else
         {
-          result+="   :";
+          result+="الفئات التي ينتمون إليها:";
         }
       }
       return result;
@@ -327,40 +327,40 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
-    { return "   :"; }
+    { return "هذه قائمة بكل الأمثلة:"; }
 
     /*! This is an introduction to the page with the list of related pages */
     virtual QCString trRelatedPagesDescription()
-    { return "      :"; }
+    { return "هذه قائمة بكل صفحات التوثيق ذات الصلة:"; }
 
     /*! This is an introduction to the page with the list of class/file groups */
     virtual QCString trModulesDescription()
-    { return "   :"; }
+    { return "هذه قائمة بكل المكونات:"; }
 
     /*! This sentences is used in the annotated class/file lists if no brief
      * description is given. 
      */
     virtual QCString trNoDescriptionAvailable()
-    { return "   "; }
+    { return "لا يوجد وصف متاح"; }
     
     // index titles (the project name is prepended for these) 
 
 
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
-    { return ""; }
+    { return "التوثيق"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * index of all groups.
      */
     virtual QCString trModuleIndex()
-    { return " "; }
+    { return "فهرس المكونات"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * class hierarchy.
      */
     virtual QCString trHierarchicalIndex()
-    { return " "; }
+    { return "الفهرس الهرمي"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * annotated compound index.
@@ -369,11 +369,11 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       { 
-        return "  ";
+        return "فهرس هيكل البيانات";
       }
       else
       {
-        return " "; 
+        return "فهرس الفئة"; 
       }
     }
 
@@ -381,13 +381,13 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      * list of all files.
      */
     virtual QCString trFileIndex() 
-    { return " "; }
+    { return "فهرس الملفات"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all groups.
      */
     virtual QCString trModuleDocumentation()
-    { return " "; }
+    { return "توثيق المكون"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all classes, structs and unions.
@@ -396,11 +396,11 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "  "; 
+        return "فهرس هيكل البيانات"; 
       }
       else
       {
-        return " "; 
+        return "فهرس الفئة"; 
       }
     }
 
@@ -408,29 +408,29 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  the documentation of all files.
      */
     virtual QCString trFileDocumentation()
-    { return " "; }
+    { return "توثيق الملفات"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all examples.
      */
     virtual QCString trExampleDocumentation()
-    { return " "; }
+    { return "توثيق الأمثلة"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all related pages.
      */
     virtual QCString trPageDocumentation()
-    { return " "; }
+    { return "توثيق الصفحات"; }
 
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
-    { return " "; }
+    { return "الكتيب المرجعي"; }
     
     /*! This is used in the documentation of a file as a header before the 
      *  list of defines
      */
     virtual QCString trDefines()
-    { return ""; }
+    { return "التعريفات"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of function prototypes
@@ -448,19 +448,19 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  list of enumerations
      */
     virtual QCString trEnumerations()
-    { return ""; }
+    { return "العدديات"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of (global) functions
      */
     virtual QCString trFunctions()
-    { return ""; }
+    { return "الدوال"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of (global) variables
      */
     virtual QCString trVariables()
-    { return ""; }
+    { return "المتغيرات"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of (global) variables
@@ -502,13 +502,13 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  of documentation blocks for functions
      */
     virtual QCString trFunctionDocumentation()
-    { return " "; }
+    { return "توثيق الدالة"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for variables
      */
     virtual QCString trVariableDocumentation()
-    { return " "; }
+    { return "توثيق المتغير"; }
 
     /*! This is used in the documentation of a file/namespace/group before 
      *  the list of links to documented compounds
@@ -517,11 +517,11 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return " "; 
+        return "هياكل البيانات"; 
       }
       else
       {
-        return ""; 
+        return "الفئات"; 
       }
     }
 
@@ -539,7 +539,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trWrittenBy()
     {
-      return " ";
+      return "كتب بواسطة";
     }
 
     /*! this text is put before a class diagram */
@@ -550,7 +550,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     
     /*! this text is generated when the \\internal command is used. */
     virtual QCString trForInternalUseOnly()
-    { return "  ."; }
+    { return "للاستخدام الداخلي فقط."; }
 
     /*! this text is generated when the \\reimp command is used. */
     virtual QCString trReimplementedForInternalReasons()
@@ -558,7 +558,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
-    { return ""; }
+    { return "تنبيه"; }
 
     /*! this text is generated when the \\bug command is used. */
     virtual QCString trBugsAndLimitations()
@@ -566,11 +566,11 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
-    { return ""; }
+    { return "إصدارة"; }
 
     /*! this text is generated when the \\date command is used. */
     virtual QCString trDate()
-    { return ""; }
+    { return "تاريخ"; }
 
     /*! this text is generated when the \\return command is used. */
     virtual QCString trReturns()
@@ -578,7 +578,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     /*! this text is generated when the \\sa command is used. */
     virtual QCString trSeeAlso()
-    { return " "; }
+    { return "انظر أيضا"; }
 
     /*! this text is generated when the \\param command is used. */
     virtual QCString trParameters()
@@ -586,11 +586,11 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     /*! this text is generated when the \\exception command is used. */
     virtual QCString trExceptions()
-    { return ""; }
+    { return "استثناءات"; }
     
     /*! this text is used in the title page of a LaTeX document. */
     virtual QCString trGeneratedBy()
-    { return " "; }
+    { return "انتجت بواسطة"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990307
@@ -598,7 +598,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     
     /*! used as the title of page containing all the index of all namespaces. */
     virtual QCString trNamespaceList()
-    { return "  "; }
+    { return "قائمة مجالات الأسماء"; }
 
     /*! used as an introduction to the namespace list */
     virtual QCString trNamespaceListDescription(bool extractAll)
@@ -644,6 +644,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
         case ClassDef::Protocol:   result+=" Protocol"; break;
         case ClassDef::Category:   result+=" Category"; break;
         case ClassDef::Exception:  result+=" Exception"; break;
+        default: break;
       }
       if (isTemplate) result+=" Template";
       result+=" Reference";
@@ -764,13 +765,13 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  index of all namespaces.
      */
     virtual QCString trNamespaceIndex()
-    { return "  "; }
+    { return "فهرس مجالات الأسماء"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all namespaces.
      */
     virtual QCString trNamespaceDocumentation()
-    { return "  "; }
+    { return "توثيق مجالات الأسماء"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990522
@@ -780,7 +781,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  namespaces in a file.
      */
     virtual QCString trNamespaces()
-    { return " "; }
+    { return "مجالات الأسماء"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990728
@@ -793,19 +794,20 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
-      QCString result=(QCString)"   ";
+      QCString result=(QCString)"توثيق   ";
       switch(compType)
       {
-        case ClassDef::Class:      result+=" "; break;
-        case ClassDef::Struct:     result+=" "; break;
-        case ClassDef::Union:      result+=" "; break;
-        case ClassDef::Interface:  result+=" "; break;
-        case ClassDef::Protocol:   result+=" "; break;
-        case ClassDef::Category:   result+=" "; break;
-        case ClassDef::Exception:  result+=" "; break;
+        case ClassDef::Class:      result+="هذه الفئة"; break;
+        case ClassDef::Struct:     result+="هذا البناء"; break;
+        case ClassDef::Union:      result+="هذا الإتحاد"; break;
+        case ClassDef::Interface:  result+="هذه الواجهة"; break;
+        case ClassDef::Protocol:   result+="هذا البروتوكول"; break;
+        case ClassDef::Category:   result+="هذا التصنيف"; break;
+        case ClassDef::Exception:  result+="هذا الإستثناء"; break;
+        default: break;
       }
-      result+="    ";
-	  if (single) result+=" :"; else result+=" :";
+      result+=" تم تكوينه من ";
+	  if (single) result+="هذا الملف:"; else result+="هذه الملفات:";
       return result;
     }
 
@@ -813,7 +815,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      * list.
      */
     virtual QCString trAlphabeticalList()
-    { return " "; }
+    { return "قائمة أبجدية"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990901
@@ -821,18 +823,18 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     /*! This is used as the heading text for the retval command. */
     virtual QCString trReturnValues()
-    { return " "; }
+    { return "قيم العودة"; }
 
     /*! This is in the (quick) index as a link to the main page (index.html)
      */
     virtual QCString trMainPage()
-    { return " "; }
+    { return "الصفحة الرئيسية"; }
 
     /*! This is used in references to page that are put in the LaTeX 
      *  documentation. It should be an abbreviation of the word page.
      */
     virtual QCString trPageAbbreviation()
-    { return "."; }
+    { return "ص."; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-991003
@@ -840,7 +842,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     virtual QCString trSources()
     {
-      return "";
+      return "مصادر";
     }
     virtual QCString trDefinedAtLineInSourceFile()
     {
@@ -867,68 +869,68 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! this text is put before a collaboration diagram */
     virtual QCString trCollaborationDiagram(const char *clName)
     {
-      return (QCString)"   "+clName+":";
+      return (QCString)"رسم التعاون لـ "+clName+":";
     }
     /*! this text is put before an include dependency graph */
     virtual QCString trInclDepGraph(const char *fName)
     {
-      return (QCString)"    "+fName+":";
+      return (QCString)"رسم اعتمادية التضمين لـ "+fName+":";
     }
     /*! header that is put before the list of constructor/destructors. */
     virtual QCString trConstructorDocumentation()
     {
-      return "   "; 
+      return "توثيق دوال البناء والهدم"; 
     }
     /*! Used in the file documentation to point to the corresponding sources. */
     virtual QCString trGotoSourceCode()
     {
-      return "     .";
+      return "اذهب إلى الكود الخاص بهذا الملف.";
     }
     /*! Used in the file sources to point to the corresponding documentation. */
     virtual QCString trGotoDocumentation()
     {
-      return "    .";
+      return "اذهب إلى توثيق هذا الملف.";
     }
     /*! Text for the \\pre command */
     virtual QCString trPrecondition()
     {
-      return " ";
+      return "شرط سابق";
     }
     /*! Text for the \\post command */
     virtual QCString trPostcondition()
     {
-      return " ";
+      return "شرط لاحق";
     }
     /*! Text for the \\invariant command */
     virtual QCString trInvariant()
     {
-      return "";
+      return "ثابت";
     }
     /*! Text shown before a multi-line variable/enum initialization */
     virtual QCString trInitialValue()
     {
-		return " :";
+		return "قيمة مبدئية:";
     }
     /*! Text used the source code in the file index */
     virtual QCString trCode()
     {
-      return "";
+      return "كود";
     }
     virtual QCString trGraphicalHierarchy()
     {
-      return "  ";
+      return "الشكل الرسومي للفئات";
     }
     virtual QCString trGotoGraphicalHierarchy()
     {
-      return "     ";
+      return "اذهب إلى الشكل الهرمي الرسومي للفئات";
     }
     virtual QCString trGotoTextualHierarchy()
     {
-      return "     ";
+      return "اذهب إلى الشكل الهرمي النصي للفئات";
     }
     virtual QCString trPageIndex()
     {
-      return " ";
+      return "فهرس الصفحات";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -937,50 +939,50 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     
     virtual QCString trNote()
     {
-      return "";
+      return "ملاحظات";
     }
     virtual QCString trPublicTypes()
     {
-      return " ";
+      return "أنواع عامة";
     }
     virtual QCString trPublicAttribs()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return " ";
+        return "حقول بيانات";
       }
       else
       {
-        return " ";
+        return "صفات عامة";
       }
     }
     virtual QCString trStaticPublicAttribs()
     {
-      return "  ";
+      return "صفات ساكنة عامة";
     }
     virtual QCString trProtectedTypes()
     {
-      return " ";
+      return "أنواع محمية";
     }
     virtual QCString trProtectedAttribs()
     {
-      return " ";
+      return "صفات محمية";
     }
     virtual QCString trStaticProtectedAttribs()
     {
-      return "  ";
+      return "صفات ساكنة محمية";
     }
     virtual QCString trPrivateTypes()
     {
-      return " ";
+      return "أنواع خاصة";
     }
     virtual QCString trPrivateAttribs()
     {
-      return " ";
+      return "صفات خاصة";
     }
     virtual QCString trStaticPrivateAttribs()
     {
-      return "  ";
+      return "صفات ساكنة خاصة";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -990,12 +992,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as a marker that is put before a \\todo item */
     virtual QCString trTodo()
     {
-      return "";
+      return "مهام";
     }
     /*! Used as the header of the todo list */
     virtual QCString trTodoList()
     {
-      return " ";
+      return "قائمة المهام";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1004,24 +1006,24 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
 
     virtual QCString trReferencedBy()
     {
-      return " ";
+      return "ذكر بواسطة";
     }
     virtual QCString trRemarks()
     {
-      return "";
+      return "تعليقات";
     }
     virtual QCString trAttention()
     {
-      return "";
+      return "انتبه";
     }
     virtual QCString trInclByDepGraph()
     {
-      return "       "
-             "    :";
+      return "هذا الرسم يوضح الملفات التي ضمنت هذا الملف"
+             "بصورة مباشرة أو غير مباشرة:";
     }
     virtual QCString trSince()
     {
-      return "";
+      return "منذ";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1111,12 +1113,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as a marker that is put before a test item */
     virtual QCString trTest()
     {
-      return "";
+      return "اختبار";
     }
     /*! Used as the header of the test list */
     virtual QCString trTestList()
     {
-      return " ";
+      return "قائمة الإختبارات";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1136,12 +1138,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as a section header for IDL properties */
     virtual QCString trProperties()
     {
-      return "";
+      return "خصائص";
     }
     /*! Used as a section header for IDL property documentation */
     virtual QCString trPropertyDocumentation()
     {
-      return " ";
+      return "توثيق الخاصية";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1151,49 +1153,49 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used for Java interfaces in the summary section of Java packages */
     virtual QCString trInterfaces()
     {
-      return "";
+      return "واجهات";
     }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return " ";
+        return "هياكل البيانات";
       }
       else
       {
-        return "";
+        return "فئات";
       }
     }
     /*! Used as the title of a Java package */
     virtual QCString trPackage(const char *name)
     {
-      return (QCString)" "+name;
+      return (QCString)"حزمة "+name;
     }
     /*! Title of the package index page */
     virtual QCString trPackageList()
     {
-      return " ";
+      return "قائمة الحزم";
     }
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
     {
-		return "        ) ( :";	  
+		return "هذه هي الحزم مع وصف مختصر لكل منها )إن وجد( :";	  
     }
     /*! The link name in the Quick links header for each page */
     virtual QCString trPackages()
     {
-      return "";
+      return "حزم";
     }
     /*! Used as a chapter title for Latex & RTF output */
     virtual QCString trPackageDocumentation()
     {
-      return " ";
+      return "توثيق الحزم";
     }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
-		return ":";
+		return "القيمة:";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1203,12 +1205,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
-      return "";
+      return "ثغرة";
     }
     /*! Used as the header of the bug list */
     virtual QCString trBugList()
     {
-      return " ";
+      return "قائمة الثغرات";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1257,7 +1259,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     /*! Used as header RTF general index */
     virtual QCString trRTFGeneralIndex()
     {
-      return "";
+      return "فهرس";
     }
    
     /*! This is used for translation of the word that will possibly
@@ -1266,8 +1268,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trClass(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("فئة");
+      if (!singular)  result="فئات";
       return result; 
     }
 
@@ -1277,8 +1279,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trFile(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("ملف");
+      if (!singular)  result="ملفات";
       return result; 
     }
 
@@ -1288,8 +1290,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trNamespace(bool /*first_capital*/, bool singular)
     { 
-      QCString result(" ");
-      if (!singular)  result=" ";
+      QCString result("مجال أسماء");
+      if (!singular)  result="مجالات أسماء";
       return result; 
     }
 
@@ -1299,8 +1301,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trGroup(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("مجموعة");
+      if (!singular)  result="مجموعات";
       return result; 
     }
 
@@ -1310,8 +1312,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trPage(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("صفحة");
+      if (!singular)  result="صفحات";
       return result; 
     }
 
@@ -1321,8 +1323,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trMember(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("عضو");
+      if (!singular)  result="أعضاء";
       return result; 
     }
    
@@ -1332,8 +1334,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trField(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("حقل");
+      if (!singular)  result="حقول";
       return result; 
     }
 
@@ -1343,8 +1345,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trGlobal(bool /*first_capital*/, bool singular)
     { 
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("عام");
+      if (!singular)  result="عوام";
       return result; 
     }
 
@@ -1356,8 +1358,8 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  for the author section in man pages. */
     virtual QCString trAuthor(bool /*first_capital*/, bool singular)
     {                                                                         
-      QCString result("");
-      if (!singular)  result="";
+      QCString result("المؤلف");
+      if (!singular)  result="المؤلفون";
       return result; 
     }
 
@@ -1369,7 +1371,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trReferences()
     {
-      return "";
+      return "مرجعيات";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1401,7 +1403,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trRTFTableOfContents()
     {
-      return " ";
+      return "جدول المحتويات";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1425,12 +1427,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trEvents()
     {
-      return "";
+      return "الأحداث";
     }
     /*! Header used for the documentation section of a class' events. */
     virtual QCString trEventDocumentation()
     {
-      return " ";
+      return "توثيق الأحداث";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1441,35 +1443,35 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trPackageTypes()
     { 
-      return " ";
+      return "أنواع الحزمة";
     }
     /*! Used as a heading for a list of Java class functions with package 
      * scope. 
      */
     virtual QCString trPackageMembers()
     { 
-      return " ";
+      return "دوال الحزمة";
     }
     /*! Used as a heading for a list of static Java class functions with 
      *  package scope.
      */
     virtual QCString trStaticPackageMembers()
     { 
-      return "  ";
+      return "دوال ساكنة للحزمة";
     }
     /*! Used as a heading for a list of Java class variables with package 
      * scope.
      */
     virtual QCString trPackageAttribs()
     { 
-      return " ";
+      return "خصائص الحزمة";
     }
     /*! Used as a heading for a list of static Java class variables with 
      * package scope.
      */
     virtual QCString trStaticPackageAttribs()
     { 
-      return "  ";
+      return "خصائص ساكنة للحزمة";
     }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1481,12 +1483,12 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trAll()
     {
-      return "";
+      return "الكل";
     }
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
     {
-		return "     :";
+		return "هذا هو رسم الاستدعاء لهذه الدالة:";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1499,14 +1501,14 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trSearchForIndex()
     {
-      return " ";
+      return "بحث عن";
     }
     /*! This string is used as the title for the page listing the search
      *  results.
      */
     virtual QCString trSearchResultsTitle()
     {
-      return " ";
+      return "نتائج البحث";
     }
     /*! This string is put just before listing the search results. The
      *  text can be different depending on the number of documents found.
@@ -1520,16 +1522,16 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
     {
       if (numDocuments==0)
       {
-        return "        .";
+        return "عفوا ، لا يوجد توثيق ملائم لما بحثت عنه.";
       }
       else if (numDocuments==1)
       {
-        return "    . <b>1</b>   .";
+        return "وثيقة مناسبة لما بحثت عنه. <b>1</b> تم العثور على.";
       }
       else 
       {
-        return "     <b>$num</b>   ."
-               "       .";
+        return "وثيقة مطابقة لما بحثت عنه <b>$num</b> تم إيجاد ."
+               "وتم ترتيبهم بحيث يكون الأقرب لنتيجة البحث أولا.";
       }
     }
     /*! This string is put before the list of matched words, for each search 
@@ -1537,7 +1539,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trSearchMatches()
     {
-		return " :";
+		return "يتطابق مع:";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1548,7 +1550,7 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trSourceFile(QCString& filename)
     {
-      return "  " + filename ;
+      return " ملف المصدر" + filename ;
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1559,33 +1561,33 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      *  hierarchy.
      */
     virtual QCString trDirIndex()
-    { return "  "; }
+    { return "شكل هرمي للأدلة"; }
 
     /*! This is used as the name of the chapter containing the documentation
      *  of the directories.
      */
     virtual QCString trDirDocumentation()
-    { return " "; }
+    { return "توثيق الأدلة"; }
 
     /*! This is used as the title of the directory index and also in the
      *  Quick links of an HTML page, to link to the directory hierarchy.
      */
     virtual QCString trDirectories()
-    { return ""; }
+    { return "الأدلة"; }
 
     /*! This returns a sentences that introduces the directory hierarchy. 
      *  and the fact that it is sorted alphabetically per level
      */
     virtual QCString trDirDescription()
-    { return "        ɡ "
-	"   :";
+    { return "هذا الشكل الهرمي للأدلة تم ترتيبه أبجديا بصورة تقريبية، "
+	"وليس ترتيبا أبجديا كاملا:";
     }
 
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
     virtual QCString trDirReference(const char *dirName)
-    { QCString result="  "; result+=dirName; return result; }
+    { QCString result=" مرجع الدليل"; result+=dirName; return result; }
 
     /*! This returns the word directory with or without starting capital
      *  (\a first_capital) and in sigular or plural form (\a singular).
@@ -1606,9 +1608,9 @@ class TranslatorArabic : public TranslatorAdapter_1_4_6
      */
     virtual QCString trOverloadText()
     {
-       return "     "
-              "  .     "
-              "    argument(s)  .";
+       return "هذه دالة عضو زائدة التحميل ،"
+              "وجد أنها ملائمة. إنها تختلف عن الدالة أعلاه"
+              "فقط في نوعية ال argument(s) التي تقبلها.";
     }
 };
 
