@@ -641,6 +641,7 @@ class TranslatorKorean : public TranslatorAdapter_1_7_5
         case ClassDef::Protocol:   result+=" "; break;
         case ClassDef::Category:   result+=" īװ"; break;
         case ClassDef::Exception:  result+=" "; break;
+        default: break;
       }
       if (isTemplate) result+=" ø";
       result+=" ";
@@ -800,6 +801,7 @@ class TranslatorKorean : public TranslatorAdapter_1_7_5
         case ClassDef::Protocol:   result+=""; break;
         case ClassDef::Category:   result+="īװ"; break;
         case ClassDef::Exception:  result+=""; break;
+        default: break;
       }
       result+="  ȭ   ";
       if (!single) result+="";
@@ -1691,6 +1693,7 @@ class TranslatorKorean : public TranslatorAdapter_1_7_5
         case ClassDef::Protocol:   result+=" "; break;
         case ClassDef::Category:   result+=" īװ"; break;
         case ClassDef::Exception:  result+=" "; break;
+        default: break;
       }
       if (isTemplate) result+=" ø";
       result+=" ";
@@ -1761,6 +1764,7 @@ class TranslatorKorean : public TranslatorAdapter_1_7_5
         case ClassDef::Protocol:   result+=""; break;
         case ClassDef::Category:   result+="īװ"; break;
         case ClassDef::Exception:  result+=""; break;
+        default: break;
       }
       result+=" ȭ :";
       return result;
@@ -1933,6 +1937,125 @@ class TranslatorKorean : public TranslatorAdapter_1_7_5
     virtual QCString trAdditionalInheritedMembers()
     { return "߰ ӵ "; }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.2
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a tooltip for the toggle button that appears in the
+     *  navigation tree in the HTML output when GENERATE_TREEVIEW is 
+     *  enabled. This tooltip explains the meaning of the button.
+     */
+    virtual QCString trPanelSynchronisationTooltip(bool enable)
+    {
+      QCString opt = enable ? "Ȱȭ" : "Ȱȭ";
+      return "г ȭ "+opt+"ϱ  ŬϽʽÿ";
+    }
+
+    /*! Used in a method of an Objective-C class that is declared in a
+     *  a category. Note that the @1 marker is required and is replaced
+     *  by a link.
+     */
+    virtual QCString trProvidedByCategory()
+    {
+      return "īװ @1  .";
+    }
+
+    /*! Used in a method of an Objective-C category that extends a class.
+     *  Note that the @1 marker is required and is replaced by a link to
+     *  the class method.
+     */
+    virtual QCString trExtendsClass()
+    {
+      return "Ŭ @1 Ȯ.";
+    }
+
+    /*! Used as the header of a list of class methods in Objective-C.
+     *  These are similar to static public member functions in C++.
+     */
+    virtual QCString trClassMethods()
+    {
+      return "Ŭ ޼ҵ";
+    }
+
+    /*! Used as the header of a list of instance methods in Objective-C.
+     *  These are similar to public member functions in C++.
+     */
+    virtual QCString trInstanceMethods()
+    {
+      return "νϽ ޼ҵ";
+    }
+
+    /*! Used as the header of the member functions of an Objective-C class.
+     */
+    virtual QCString trMethodDocumentation()
+    {
+      return "޼ҵ ȭ";
+    }
+
+    /*! Used as the title of the design overview picture created for the
+     *  VHDL output.
+     */
+    virtual QCString trDesignOverview()
+    {
+      return " ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.4
+//////////////////////////////////////////////////////////////////////////
+
+    /** old style UNO IDL services: implemented interfaces */
+    virtual QCString trInterfaces()
+    { return "ͽƮ ̽"; }
+
+    /** old style UNO IDL services: inherited services */
+    virtual QCString trServices()
+    { return "Ե 񽺵"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroups()
+    { return " ׷"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroupReference(const char *namespaceName)
+    {
+      QCString result=namespaceName;
+      result+="  ׷ ۷";
+      return result;
+    }
+    /** UNO IDL service page title */
+    virtual QCString trServiceReference(const char *sName)
+    {
+      QCString result=(QCString)sName;
+      result+="  ۷";
+      return result;
+    }
+    /** UNO IDL singleton page title */
+    virtual QCString trSingletonReference(const char *sName)
+    {
+      QCString result=(QCString)sName;
+      result+=" ̱ ۷";
+      return result;
+    }
+    /** UNO IDL service page */
+    virtual QCString trServiceGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)" 񽺿  ȭ  ";
+      if (!single) result+="";
+	  result+="κ Ǿϴ.:";
+      return result;
+    }
+    /** UNO IDL singleton page */
+    virtual QCString trSingletonGeneratedFromFiles(bool single)
+    {
+      // single is true implies a single file
+      QCString result=(QCString)" ̱濡  ȭ  ";
+      if (!single) result+="";
+	  result+="κ Ǿϴ.:";
+      return result;
+    }
+
 //////////////////////////////////////////////////////////////////////////
 
 };
