@@ -380,6 +380,7 @@ bool patternMatch(const QFileInfo &fi,const QStrList *patList);
 QCString externalLinkTarget();
 QCString externalRef(const QCString &relPath,const QCString &ref,bool href);
 int nextUtf8CharPosition(const QCString &utf8Str,int len,int startPos);
+const char *writeUtf8Char(FTextStream &t,const char *s);
 
 /** Data associated with a HSV colored image. */
 struct ColoredImgDataItem
@@ -407,5 +408,7 @@ QCString stripIndentation(const QCString &s);
 
 bool fileVisibleInIndex(FileDef *fd,bool &genSourceFile);
 
+void addDocCrossReference(MemberDef *src,MemberDef *dst);
+
 #endif
 
