@@ -28,7 +28,7 @@
 #include <unistd.h>
 #include <qfile.h>
 #include <qdict.h>
-
+#include "vhdldocgen.h"
 #include "entry.h"
 
 class Entry;
@@ -48,9 +48,13 @@ class VHDLLanguageScanner : public ParserInterface
 {
   public:
     virtual ~VHDLLanguageScanner() {}
+    void startTranslationUnit(const char *) {}
+    void finishTranslationUnit() {}
     void parseInput(const char * fileName, 
                     const char *fileBuf, 
-                    Entry *root);
+                    Entry *root,
+                    bool sameTranslationUnit,
+                    QStrList &filesInSameTranslationUnit);
     bool needsPreprocessing(const QCString &extension);
     void parseCode(CodeOutputInterface &codeOutIntf,
                    const char *scopeName,
@@ -129,8 +133,13 @@ void vhdlParse();
 // return the list of component instantiations e.g. foo: component bar 
 QList<Entry> &  getVhdlInstList();
 
-// returns the list of found configurations
+// returns   configuration list
 QList<VhdlConfNode>& getVhdlConfiguration();
 
+// returns library/used list
+QList<Entry> &  getLibUse();
+
 void isVhdlDocPending();
+
+
 #endif
