@@ -173,7 +173,7 @@ void XmlDocVisitor::visit(DocSymbol *s)
     case DocSymbol::LeftFloor:     m_t << "<lfloor>"; break;
     case DocSymbol::RightFloor:    m_t << "<rfloor>"; break;
     default:
-                             err("error: unknown symbol found\n");
+                             err("unknown symbol found\n");
   }
 }
 
@@ -283,6 +283,11 @@ void XmlDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::XmlOnly: 
       m_t << s->text();
       break;
+    case DocVerbatim::DocbookOnly:
+      m_t << "<docbookonly>";
+      filter(s->text());
+      m_t << "</docbookonly>";
+      break;
     case DocVerbatim::Dot: 
       m_t << "<dot>";
       filter(s->text());
